#
# spec file for package ServiceReport
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libversion %(echo %{version} | sed -e "s/+git.*//")

# By default python 3 is used to build the package.
%define python python3
Name:           ServiceReport
Version:        2.2.4+git7.8ca0fe4
Release:        1.1
Summary:        A tool to validate and repair First Failure Data Capture (FFDC) configuration
License:        GPL-2.0-only
Group:          System/Management
URL:            https://github.com/linux-ras/ServiceReport
Source:         %{name}-%{version}.tar.xz
BuildRequires:  %{python}
BuildRequires:  %{python}-setuptools
BuildRequires:  python-rpm-macros
BuildRequires:  systemd-rpm-macros
%systemd_requires
BuildArch:      noarch

%description
ServiceReport is a python based tool that investigates the incorrect
First Failure Data Capture (FFDC) configuration and optionally repairs
the incorrect configuration

%define debug_package %{nil}

%prep
%setup -q
%autopatch -p1

%build
%{python} setup.py build

%install
%{python} setup.py install --root=%{buildroot}

%pre
%service_add_pre servicereport.service

%post
%service_add_post servicereport.service

%preun
%service_del_preun servicereport.service

%postun
%service_del_postun servicereport.service

%files
%license COPYING
%{_mandir}/man8/*
%doc %{_datadir}/doc/*
%{_bindir}/servicereport
%{_unitdir}/servicereport.service

%if "%{python}" == "python3"
%{python3_sitelib}/servicereportpkg
%{python3_sitelib}/%{name}-%{libversion}*.egg-info
%else
%{python_sitelib}/servicereportpkg
%{python_sitelib}/%{name}-%{libversion}*.egg-info
%endif

%changelog
* Fri Jun 20 2025 msuchanek@suse.de
- Update to version 2.2.4+git7.8ca0fe4:
  * [utils] update logic to parse /etc/os-release (bsc#1244547 ltc#213710)
  * Added hardening to systemd service
* Fri Apr 18 2025 msuchanek@suse.de
- Update to version 2.2.4+git5.e48c02c:
  * Added hardening to systemd service
- Drop upstreamed patch harden_servicereport.service.patch
* Wed Oct 23 2024 msuchanek@suse.de
- Update to version 2.2.4+git2.f1e4503:
  * [Service] Make the servicereport service dependent on the kdump service
  * [utils] Use --update-bls-cmdline Option for GRUB Update
- Refresh harden_servicereport.service.patch
* Tue Feb 27 2024 msuchanek@suse.com
- Update to version 2.2.4 (bsc#1220410 ltc#204408)
  * ServiceReport v2.2.4 release
  * [kdump] update /etc/sysconfig/kdump config processing
  * [kdump] customize initrd dump component check for SLES
  * [fadump] update initrd validation check
  * [kdump] restrict lsinitrd command to fetch only modules
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Tue Dec 14 2021 Michal Suchanek <msuchanek@suse.com>
- Fix build on SLE 15: python-rpm-macros required for build (bsc#1193718).
* Fri Sep 24 2021 msuchanek@suse.de
- Update to version 2.2.3+git1.55a13db1c256:
  * [fadump] Update crashkernel recommendation (tid#7023277).
* Tue Jul 27 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s). Added harden_servicereport.service.patch
* Thu Jul 15 2021 msuchanek@suse.com
- Update to version 2.2.3 (jsc#SLE-18193):
  * ServiceReport v2.2.3 release
  * [Daemon] check active status along with enabled
  * Run-on supported architectures only
  * Take crashkernel recommendation from kdump-lib.sh scripts
* Wed Feb  3 2021 Michal Suchanek <msuchanek@suse.de>
- Update to version 2.2.2+git10.1caca0630e36 (bsc#1181729 ltc#191203):
  * Update SLES crashkernel recommendation values
  * update HTX service name
- Remove the already included patches
  - 0001-Add-active-dump-check-in-kdump-and-FADump-plugin.patch
  - 0002-Introduce-a-new-option-to-mark-plugins-optional.patch
  - 0003-HTX-Mark-HTX-plugin-as-optional.patch
  - 0004-Add-new-option-to-run-all-applicable-plugins.patch
  - 0005-Allow-distro-classes-to-redefine-the-capture-kernel-.patch
  - 0006-utils-remove-the-invalid-function-call-to-walk_packa.patch
  - 0007-Update-data-files-of-the-project.patch
  - 0008-Run-servicereport-using-python3-binary.patch
* Tue Nov  3 2020 Michal Suchanek <msuchanek@suse.de>
- Update to upstream git (jsc#SLE-13288).
  + 0001-Add-active-dump-check-in-kdump-and-FADump-plugin.patch
  + 0002-Introduce-a-new-option-to-mark-plugins-optional.patch
  + 0003-HTX-Mark-HTX-plugin-as-optional.patch
  + 0004-Add-new-option-to-run-all-applicable-plugins.patch
  + 0005-Allow-distro-classes-to-redefine-the-capture-kernel-.patch
  + 0006-utils-remove-the-invalid-function-call-to-walk_packa.patch
  + 0007-Update-data-files-of-the-project.patch
  + 0008-Run-servicereport-using-python3-binary.patch
* Wed Sep  2 2020 Michal Suchanek <msuchanek@suse.com>
- Run throuhg spec-cleaner and split off changelog.
- Fix license and dependencies
- Re-download the source
* Sun May 17 2020 Sourbh Jain <sourabhjain@linux.ibm.com>
- Move setup.cfg metadata to setup.py file
* Thu May 14 2020 Sourabh Jain <sourabhjain@linux.ibm.com>
  Update to version 2.2.2
- Update crashkernel memory reservation limit
- Remove rpm postscript
- Add servicereport.spec file
- Move systemd service file to a generic location
- Run service only once at boot time without repair action
- fix initrd repair function
- [fadump] No boolean return from check_* function
- [fadump] indent the code with spaces instead of tabs
- Fix the option_string for --plugin option
- [fadump] update the logic to extract the FADump mem reservation
- Add irqbalance daemon check
- Add irqbalance package check
- Fix the system platform string extraction from /proc/cpuinfo
- Fix powerpc-ibm-utils package name
- Fix typo in README.md
* Fri Nov 15 2019 Sourabh Jain <sourabhjain@linux.ibm.com>
  Version 2.2.1
- First Open source release
- Initial Commit of Open Source release
